@@ -2,12 +2,12 @@
 from robster.model import LinearModel
 
 class SingleLayerPerceptron:
-  def __init__(self, epochs, mini_batch, MODEL = LinearModel, learning_rate = 0.001, report = 1):
-    self.epochs = epochs
-    self.mini_batch = mini_batch
-    self.learning_rate = learning_rate
-    self.report=report
-    self.MODEL = MODEL
+  def __init__(self, epochs_, mini_batch_, MODEL_ = LinearModel, learning_rate_ = 0.001, report_ = 1):
+    self.epochs = epochs_
+    self.mini_batch = mini_batch_
+    self.learning_rate = learning_rate_
+    self.report=report_
+    self.MODEL = MODEL_
 
 
   def fit(self, X, y):
